<?php
/**
 * Template for displaying additional info of the single course.
 *
 * @package FRIBBO
 * @since FRIBBO 1.0.62
 */

/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

$fribbo_course_id = get_the_ID();
$fribbo_course    = learn_press_get_course( $fribbo_course_id );
$fribbo_author    = $fribbo_course->get_author();
$fribbo_terms     = get_the_terms( $fribbo_course_id, 'course_category' );
$fribbo_cat       = !empty($fribbo_terms) ? '<a href="' . esc_url( get_term_link( $fribbo_terms[0], 'course_category' ) ) . '">' . esc_html( $fribbo_terms[0]->name ) . '</a>' : '';
$fribbo_students  = ! $fribbo_course || ! $fribbo_course->is_required_enroll() ? 0 : (int) $fribbo_course->count_students();
?>
<div class="entry-meta lp_single_course_meta">
	<div class="lp_single_course_meta_item lp_single_course_meta_item_author entry-author">
		<div class="author vcard">
			<?php echo get_avatar( get_post_field( 'post_author', get_the_ID() ), 60 ); ?>
			<div class="lp_single_course_meta_item_info">
				<label><?php esc_html_e( 'Teacher', 'fribbo' ); ?></label>
				<span class="author_name"><?php echo esc_html( $fribbo_author->get_data( 'display_name' ) ); ?></span>
			</div>
		</div>
	</div>
	<?php
	if ( $fribbo_cat ) {
		?>
		<div class="lp_single_course_meta_item lp_single_course_meta_item_category entry-category">
			<label><?php esc_html_e( 'Categories', 'fribbo' ); ?></label>
			<?php printf( '<span class="category_link">%s</span>', $fribbo_cat ); ?>
		</div>
		<?php
	}
	// Get course bbpress forum
	$fribbo_forum_id = get_post_meta( $fribbo_course->get_id(), '_lp_course_forum', true );
	if ( $fribbo_forum_id && class_exists( 'LP_Addon_bbPress' ) && class_exists( 'bbPress' ) ) {
		?>
		<div class="lp_single_course_meta_item lp_single_course_meta_item_forum entry-forum">
			<label><?php esc_html_e( 'Visit Forum: ', 'fribbo' ); ?></label>
			<?php LP_Addon_bbPress::instance()->forum_link(); ?>
		</div>
		<?php
	}
	// Course students
	if ( $fribbo_students > 0 ) {
		?>
		<div class="lp_single_course_meta_item lp_single_course_meta_item_students">
			<label><?php esc_html_e( 'Students', 'fribbo' ); ?></label>
			<span><?php echo esc_html( $fribbo_students ); ?></span>
		</div>
	    <?php
	}
	// Course rating
	if ( function_exists( "learn_press_get_course_rate" ) ) {
		$fribbo_total           = 0;
		$fribbo_course_rate     = 0;
		$fribbo_course_rate_res = learn_press_get_course_rate( $fribbo_course_id, false );
		$fribbo_course_rate     = $fribbo_course_rate_res['rated'];
		$fribbo_total           = (int) $fribbo_course_rate_res['total'];
		?>
		<div class="lp_single_course_meta_item lp_single_course_meta_item_review entry-review">
			<label><?php
				if ( is_single() ) {
					if ( $fribbo_total > 0 ) {
						printf( esc_html( _n( '%s Review', '%s Reviews', $fribbo_total, 'fribbo' ) ), $fribbo_total );
					} else {
						printf( esc_html__( '%s Review', 'fribbo' ), $fribbo_total );
					}
				} else {
					printf( esc_html( _n( '%s Rating', '%s Ratings', $fribbo_total, 'fribbo' ) ), $fribbo_total );
				}
			?></label>
			<div class="lp_single_course_meta_item_rating">
				<?php learn_press_course_review_template( 'rating-stars.php', array( 'rated' => $fribbo_course_rate ) ); ?>
				<span><?php printf( '%1.1f', $fribbo_course_rate ); ?></span>
			</div>
		</div>
		<?php
	}
	?>
</div>
