<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package FRIBBO
 * @since FRIBBO 1.0
 */

if ( fribbo_sidebar_present() ) {
	
	$fribbo_sidebar_type = fribbo_get_theme_option( 'sidebar_type' );
	if ( 'custom' == $fribbo_sidebar_type && ! fribbo_is_layouts_available() ) {
		$fribbo_sidebar_type = 'default';
	}
	
	// Catch output to the buffer
	ob_start();
	if ( 'default' == $fribbo_sidebar_type ) {
		// Default sidebar with widgets
		$fribbo_sidebar_name = fribbo_get_theme_option( 'sidebar_widgets' );
		fribbo_storage_set( 'current_sidebar', 'sidebar' );
		if ( is_active_sidebar( $fribbo_sidebar_name ) ) {
			dynamic_sidebar( $fribbo_sidebar_name );
		}
	} else {
		// Custom sidebar from Layouts Builder
		$fribbo_sidebar_id = fribbo_get_custom_sidebar_id();
		do_action( 'fribbo_action_show_layout', $fribbo_sidebar_id );
	}
	$fribbo_out = trim( ob_get_contents() );
	ob_end_clean();
	
	// If any html is present - display it
	if ( ! empty( $fribbo_out ) ) {
		$fribbo_sidebar_position    = fribbo_get_theme_option( 'sidebar_position' );
		$fribbo_sidebar_position_ss = fribbo_get_theme_option( 'sidebar_position_ss' );
		?>
		<div class="sidebar widget_area
			<?php
			echo ' ' . esc_attr( $fribbo_sidebar_position );
			echo ' sidebar_' . esc_attr( $fribbo_sidebar_position_ss );
			echo ' sidebar_' . esc_attr( $fribbo_sidebar_type );

			if ( 'float' == $fribbo_sidebar_position_ss ) {
				echo ' sidebar_float';
			}
			$fribbo_sidebar_scheme = fribbo_get_theme_option( 'sidebar_scheme' );
			if ( ! empty( $fribbo_sidebar_scheme ) && ! fribbo_is_inherit( $fribbo_sidebar_scheme ) ) {
				echo ' scheme_' . esc_attr( $fribbo_sidebar_scheme );
			}
			?>
		" role="complementary">
			<?php

			// Skip link anchor to fast access to the sidebar from keyboard
			?>
			<a id="sidebar_skip_link_anchor" class="fribbo_skip_link_anchor" href="#"></a>
			<?php

			do_action( 'fribbo_action_before_sidebar_wrap', 'sidebar' );

			// Button to show/hide sidebar on mobile
			if ( in_array( $fribbo_sidebar_position_ss, array( 'above', 'float' ) ) ) {
				$fribbo_title = apply_filters( 'fribbo_filter_sidebar_control_title', 'float' == $fribbo_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'fribbo' ) : '' );
				$fribbo_text  = apply_filters( 'fribbo_filter_sidebar_control_text', 'above' == $fribbo_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'fribbo' ) : '' );
				?>
				<a href="#" class="sidebar_control" title="<?php echo esc_attr( $fribbo_title ); ?>"><?php echo esc_html( $fribbo_text ); ?></a>
				<?php
			}
			?>
			<div class="sidebar_inner">
				<?php
				do_action( 'fribbo_action_before_sidebar', 'sidebar' );
				fribbo_show_layout( preg_replace( "/<\/aside>[\r\n\s]*<aside/", '</aside><aside', $fribbo_out ) );
				do_action( 'fribbo_action_after_sidebar', 'sidebar' );
				?>
			</div><!-- /.sidebar_inner -->
			<?php

			do_action( 'fribbo_action_after_sidebar_wrap', 'sidebar' );

			?>
		</div><!-- /.sidebar -->
		<div class="clearfix"></div>
		<?php
	}
}
